==> estateplat-common-1.2.4-20201121.064802-540-sources.jar: cn/gtmap/estateplat/model/server/core/XxgxZbbSydw.java <==
package cn.gtmap.estateplat.model.server.core;

import javax.persistence.Id;
import javax.persistence.Table;
import java.util.Date;

/**
 * @author <a href="mailto:qijiadong@gtmap.cn">qijiadong</a>
 * @version 1.0, 2020/11/12
 * @description 省级信息共享-事业编-事业单位
 */
@Table(name = "xxgx_zbb_sydw")
public class XxgxZbbSydw {
    @Id
    private String sydwid;//事业单位id
    private String tyshxydm;//统一社会信用代码
    private String dymc;//第一名称
    private Date bfrq;//颁发日期
    private String fmjg;//赋码机关
    private String fzr;//负责人
    private String jgdz;//机构地址
    private String jgxz;//机构性质
    private String qlbs;//权力标识
    private String qtmc;//其他名称
    private Date sjrq;//数据日期
    private String dsmc;//第三名称
    private String demc;//第二名称
    private String zt;//状态
    private String djgljg;//登记管理机关
    private String jbdw;//举办单位
    private String jfly;//经费来源
    private String kbzj;//开办资金
    private String ywlx;//业务类型
    private Date yxqs;//有效期（始）
    private Date yxqz;//有效期（至）
    private String zs;//住所
    private String zzhywfw;//宗旨和业务范围
    private String proid;//项目ID


    public String getSydwid() {
        return sydwid;
    }

    public void setSydwid(String sydwid) {
        this.sydwid = sydwid;
    }

    public String getTyshxydm() {
        return tyshxydm;
    }

    public void setTyshxydm(String tyshxydm) {
        this.tyshxydm = tyshxydm;
    }

    public String getDymc() {
        return dymc;
    }

    public void setDymc(String dymc) {
        this.dymc = dymc;
    }

    public Date getBfrq() {
        return bfrq;
    }

    public void setBfrq(Date bfrq) {
        this.bfrq = bfrq;
    }

    public String getFmjg() {
        return fmjg;
    }

    public void setFmjg(String fmjg) {
        this.fmjg = fmjg;
    }

    public String getFzr() {
        return fzr;
    }

    public void setFzr(String fzr) {
        this.fzr = fzr;
    }

    public String getJgdz() {
        return jgdz;
    }

    public void setJgdz(String jgdz) {
        this.jgdz = jgdz;
    }

    public String getJgxz() {
        return jgxz;
    }

    public void setJgxz(String jgxz) {
        this.jgxz = jgxz;
    }

    public String getQlbs() {
        return qlbs;
    }

    public void setQlbs(String qlbs) {
        this.qlbs = qlbs;
    }

    public String getQtmc() {
        return qtmc;
    }

    public void setQtmc(String qtmc) {
        this.qtmc = qtmc;
    }

    public Date getSjrq() {
        return sjrq;
    }

    public void setSjrq(Date sjrq) {
        this.sjrq = sjrq;
    }

    public String getDsmc() {
        return dsmc;
    }

    public void setDsmc(String dsmc) {
        this.dsmc = dsmc;
    }

    public String getDemc() {
        return demc;
    }

    public void setDemc(String demc) {
        this.demc = demc;
    }

    public String getZt() {
        return zt;
    }

    public void setZt(String zt) {
        this.zt = zt;
    }

    public String getDjgljg() {
        return djgljg;
    }

    public void setDjgljg(String djgljg) {
        this.djgljg = djgljg;
    }


    public String getJbdw() {
        return jbdw;
    }

    public void setJbdw(String jbdw) {
        this.jbdw = jbdw;
    }

    public String getJfly() {
        return jfly;
    }

    public void setJfly(String jfly) {
        this.jfly = jfly;
    }

    public String getKbzj() {
        return kbzj;
    }

    public void setKbzj(String kbzj) {
        this.kbzj = kbzj;
    }

    public String getYwlx() {
        return ywlx;
    }

    public void setYwlx(String ywlx) {
        this.ywlx = ywlx;
    }

    public Date getYxqs() {
        return yxqs;
    }

    public void setYxqs(Date yxqs) {
        this.yxqs = yxqs;
    }

    public Date getYxqz() {
        return yxqz;
    }

    public void setYxqz(Date yxqz) {
        this.yxqz = yxqz;
    }

    public String getZs() {
        return zs;
    }

    public void setZs(String zs) {
        this.zs = zs;
    }

    public String getZzhywfw() {
        return zzhywfw;
    }

    public void setZzhywfw(String zzhywfw) {
        this.zzhywfw = zzhywfw;
    }

    public String getProid() {
        return proid;
    }

    public void setProid(String proid) {
        this.proid = proid;
    }
}

==> estateplat-common-1.2.4-20210430.031310-741-sources.jar: cn/gtmap/estateplat/model/server/core/XxgxZbbSydw.java <==
package cn.gtmap.estateplat.model.server.core;

import javax.persistence.Id;
import javax.persistence.Table;
import java.util.Date;

/**
 * @author <a href="mailto:qijiadong@gtmap.cn">qijiadong</a>
 * @version 1.0, 2020/11/12
 * @description 省级信息共享-事业编-事业单位
 */
@Table(name = "xxgx_zbb_sydw")
public class XxgxZbbSydw {
    @Id
    private String sydwid;//事业单位id
    private String tyshxydm;//统一社会信用代码
    private String dymc;//第一名称
    private Date bfrq;//颁发日期
    private String fmjg;//赋码机关
    private String fzr;//负责人
    private String jgdz;//机构地址
    private String jgxz;//机构性质
    private String qlbs;//权力标识
    private String qtmc;//其他名称
    private Date sjrq;//数据日期
    private String dsmc;//第三名称
    private String demc;//第二名称
    private String zt;//状态
    private String djgljg;//登记管理机关
    private String jbdw;//举办单位
    private String jfly;//经费来源
    private String kbzj;//开办资金
    private String ywlx;//业务类型
    private Date yxqs;//有效期（始）
    private Date yxqz;//有效期（至）
    private String zs;//住所
    private String zzhywfw;//宗旨和业务范围
    private String proid;//项目ID
    private String cxywlb;//查询业务类别

    public String getSydwid() {
        return sydwid;
    }

    public void setSydwid(String sydwid) {
        this.sydwid = sydwid;
    }

    public String getTyshxydm() {
        return tyshxydm;
    }

    public void setTyshxydm(String tyshxydm) {
        this.tyshxydm = tyshxydm;
    }

    public String getDymc() {
        return dymc;
    }

    public void setDymc(String dymc) {
        this.dymc = dymc;
    }

    public Date getBfrq() {
        return bfrq;
    }

    public void setBfrq(Date bfrq) {
        this.bfrq = bfrq;
    }

    public String getFmjg() {
        return fmjg;
    }

    public void setFmjg(String fmjg) {
        this.fmjg = fmjg;
    }

    public String getFzr() {
        return fzr;
    }

    public void setFzr(String fzr) {
        this.fzr = fzr;
    }

    public String getJgdz() {
        return jgdz;
    }

    public void setJgdz(String jgdz) {
        this.jgdz = jgdz;
    }

    public String getJgxz() {
        return jgxz;
    }

    public void setJgxz(String jgxz) {
        this.jgxz = jgxz;
    }

    public String getQlbs() {
        return qlbs;
    }

    public void setQlbs(String qlbs) {
        this.qlbs = qlbs;
    }

    public String getQtmc() {
        return qtmc;
    }

    public void setQtmc(String qtmc) {
        this.qtmc = qtmc;
    }

    public Date getSjrq() {
        return sjrq;
    }

    public void setSjrq(Date sjrq) {
        this.sjrq = sjrq;
    }

    public String getDsmc() {
        return dsmc;
    }

    public void setDsmc(String dsmc) {
        this.dsmc = dsmc;
    }

    public String getDemc() {
        return demc;
    }

    public void setDemc(String demc) {
        this.demc = demc;
    }

    public String getZt() {
        return zt;
    }

    public void setZt(String zt) {
        this.zt = zt;
    }

    public String getDjgljg() {
        return djgljg;
    }

    public void setDjgljg(String djgljg) {
        this.djgljg = djgljg;
    }


    public String getJbdw() {
        return jbdw;
    }

    public void setJbdw(String jbdw) {
        this.jbdw = jbdw;
    }

    public String getJfly() {
        return jfly;
    }

    public void setJfly(String jfly) {
        this.jfly = jfly;
    }

    public String getKbzj() {
        return kbzj;
    }

    public void setKbzj(String kbzj) {
        this.kbzj = kbzj;
    }

    public String getYwlx() {
        return ywlx;
    }

    public void setYwlx(String ywlx) {
        this.ywlx = ywlx;
    }

    public Date getYxqs() {
        return yxqs;
    }

    public void setYxqs(Date yxqs) {
        this.yxqs = yxqs;
    }

    public Date getYxqz() {
        return yxqz;
    }

    public void setYxqz(Date yxqz) {
        this.yxqz = yxqz;
    }

    public String getZs() {
        return zs;
    }

    public void setZs(String zs) {
        this.zs = zs;
    }

    public String getZzhywfw() {
        return zzhywfw;
    }

    public void setZzhywfw(String zzhywfw) {
        this.zzhywfw = zzhywfw;
    }

    public String getProid() {
        return proid;
    }

    public void setProid(String proid) {
        this.proid = proid;
    }

    public String getCxywlb() {
        return cxywlb;
    }

    public void setCxywlb(String cxywlb) {
        this.cxywlb = cxywlb;
    }
}
